@@ -88,7 +88,8 @@ public:
 
 
 OpenconnectAuthWidget::OpenconnectAuthWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget * parent)
-    : SettingWidget(setting, parent), d_ptr(new OpenconnectAuthWidgetPrivate)
+    : SettingWidget(setting, parent)
+    , d_ptr(new OpenconnectAuthWidgetPrivate)
 {
     Q_D(OpenconnectAuthWidget);
     d->setting = setting;
@@ -102,9 +103,9 @@ OpenconnectAuthWidget::OpenconnectAuthWidget(const NetworkManager::VpnSetting::P
         d->cancelPipes[1] = -1;
     }
 
-    connect(d->ui.cmbLogLevel, SIGNAL(currentIndexChanged(int)), this, SLOT(logLevelChanged(int)));
-    connect(d->ui.viewServerLog, SIGNAL(toggled(bool)), this, SLOT(viewServerLogToggled(bool)));
-    connect(d->ui.btnConnect, SIGNAL(clicked()), this, SLOT(connectHost()));
+    connect(d->ui.cmbLogLevel, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &OpenconnectAuthWidget::logLevelChanged);
+    connect(d->ui.viewServerLog, &QCheckBox::toggled, this, &OpenconnectAuthWidget::viewServerLogToggled);
+    connect(d->ui.btnConnect, &QPushButton::clicked, this, &OpenconnectAuthWidget::connectHost);
 
     d->ui.cmbLogLevel->setCurrentIndex(OpenconnectAuthWidgetPrivate::Debug);
     d->ui.btnConnect->setIcon(QIcon::fromTheme("network-connect"));
@@ -116,17 +117,17 @@ OpenconnectAuthWidget::OpenconnectAuthWidget(const NetworkManager::VpnSetting::P
     // and which needs to be populated with settings we get from NM, like host, certificate or private key
     d->vpninfo = d->worker->getOpenconnectInfo();
 
-    connect(d->worker, SIGNAL(validatePeerCert(QString,QString,QString,bool*)), this, SLOT(validatePeerCert(QString,QString,QString,bool*)));
-    connect(d->worker, SIGNAL(processAuthForm(oc_auth_form*)), this, SLOT(processAuthForm(oc_auth_form*)));
-    connect(d->worker, SIGNAL(updateLog(QString,int)), this, SLOT(updateLog(QString,int)));
-    connect(d->worker, SIGNAL(writeNewConfig(QString)), this, SLOT(writeNewConfig(QString)));
-    connect(d->worker, SIGNAL(cookieObtained(int)), this, SLOT(workerFinished(int)));
+    connect(d->worker, static_cast<void (OpenconnectAuthWorkerThread::*)(const QString &, const QString &, const QString &, bool*)>(&OpenconnectAuthWorkerThread::validatePeerCert), this, &OpenconnectAuthWidget::validatePeerCert);
+    connect(d->worker, &OpenconnectAuthWorkerThread::processAuthForm, this, &OpenconnectAuthWidget::processAuthForm);
+    connect(d->worker, &OpenconnectAuthWorkerThread::updateLog, this, &OpenconnectAuthWidget::updateLog);
+    connect(d->worker, static_cast<void (OpenconnectAuthWorkerThread::*)(const QString&)>(&OpenconnectAuthWorkerThread::writeNewConfig), this, &OpenconnectAuthWidget::writeNewConfig);
+    connect(d->worker, &OpenconnectAuthWorkerThread::cookieObtained, this, &OpenconnectAuthWidget::workerFinished);
 
     readConfig();
     readSecrets();
 
     // This might be set by readSecrets() so don't connect it until now
-    connect(d->ui.cmbHosts, SIGNAL(currentIndexChanged(int)), this, SLOT(connectHost()));
+    connect(d->ui.cmbHosts, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &OpenconnectAuthWidget::connectHost);
 
     KAcceleratorManager::manage(this);
 }
@@ -230,13 +231,14 @@ void OpenconnectAuthWidget::readSecrets()
 
     for (int i = 0; i < d->hosts.size(); i++) {
         d->ui.cmbHosts->addItem(d->hosts.at(i).name, i);
-        if (d->secrets["lasthost"] == d->hosts.at(i).name || d->secrets["lasthost"] == d->hosts.at(i).address)
+        if (d->secrets["lasthost"] == d->hosts.at(i).name || d->secrets["lasthost"] == d->hosts.at(i).address) {
             d->ui.cmbHosts->setCurrentIndex(i);
+        }
     }
 
     if (d->secrets["autoconnect"] == "yes") {
         d->ui.chkAutoconnect->setChecked(true);
-        QTimer::singleShot(0, this, SLOT(connectHost()));
+        QTimer::singleShot(0, this, &OpenconnectAuthWidget::connectHost);
     }
 
     if (d->secrets["save_passwords"] == "yes") {
@@ -267,20 +269,23 @@ void OpenconnectAuthWidget::connectHost()
 
     /* Suck out the cancel byte(s) */
     char buf;
-    while (read(d->cancelPipes[0], &buf, 1) == 1)
+    while (read(d->cancelPipes[0], &buf, 1) == 1) {
         ;
+    }
     deleteAllFromLayout(d->ui.loginBoxLayout);
     int i = d->ui.cmbHosts->currentIndex();
-    if (i == -1)
+    if (i == -1) {
         return;
+    }
     i = d->ui.cmbHosts->itemData(i).toInt();
     const VPNHost &host = d->hosts.at(i);
     if (openconnect_parse_url(d->vpninfo, host.address.toAscii().data())) {
         qCWarning(PLASMA_NM) << "Failed to parse server URL" << host.address;
         openconnect_set_hostname(d->vpninfo, OC3DUP(host.address.toAscii().data()));
     }
-    if (!openconnect_get_urlpath(d->vpninfo) && !host.group.isEmpty())
+    if (!openconnect_get_urlpath(d->vpninfo) && !host.group.isEmpty()) {
         openconnect_set_urlpath(d->vpninfo, OC3DUP(host.group.toAscii().data()));
+    }
     d->secrets["lasthost"] = host.name;
     addFormInfo(QLatin1String("dialog-information"), i18n("Contacting host, please wait..."));
     d->worker->start();
@@ -315,10 +320,11 @@ QVariantMap OpenconnectAuthWidget::setting(bool agentOwned) const
 
     NMStringMap::iterator i = secrets.begin();
     while (i != secrets.end()) {
-        if (i.value().isEmpty())
+        if (i.value().isEmpty()) {
             i = secrets.erase(i);
-        else
+        } else {
             i++;
+        }
     }
 
     secretData.insert("secrets", QVariant::fromValue<NMStringMap>(secrets));
@@ -342,10 +348,10 @@ void OpenconnectAuthWidget::updateLog(const QString &message, const int &level)
     Q_D(OpenconnectAuthWidget);
     QPair<QString, int> pair;
     pair.first = message;
-    if (pair.first.endsWith(QLatin1String("\n")))
+    if (pair.first.endsWith(QLatin1String("\n"))) {
         pair.first.chop(1);
-    switch (level)
-    {
+    }
+    switch (level) {
     case PRG_ERR:
         pair.second = OpenconnectAuthWidgetPrivate::Error;
         break;
@@ -428,12 +434,13 @@ void OpenconnectAuthWidget::processAuthForm(struct oc_auth_form *form)
     QCheckBox *togglePasswordMode = new QCheckBox(this);
     togglePasswordMode->setText(i18n("&Show password"));
     togglePasswordMode->setChecked(false);
-    connect(togglePasswordMode, SIGNAL(toggled(bool)), this, SLOT(passwordModeToggled(bool)));
+    connect(togglePasswordMode, &QCheckBox::toggled, this, &OpenconnectAuthWidget::passwordModeToggled);
     int passwordnumber = 0;
     bool focusSet = false;
     for (opt = form->opts; opt; opt = opt->next) {
-        if (opt->type == OC_FORM_OPT_HIDDEN || IGNORE_OPT(opt))
+        if (opt->type == OC_FORM_OPT_HIDDEN || IGNORE_OPT(opt)) {
             continue;
+        }
         QLabel *text = new QLabel(this);
         text->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
         text->setText(QString(opt->label));
@@ -460,12 +467,12 @@ void OpenconnectAuthWidget::processAuthForm(struct oc_auth_form *form)
                 if (value == QString::fromUtf8(FORMCHOICE(sopt, i)->name)) {
                     cmb->setCurrentIndex(i);
                     if (sopt == AUTHGROUP_OPT(form) && i != AUTHGROUP_SELECTION(form)) {
-                        QTimer::singleShot(0, this, SLOT(formGroupChanged()));
+                        QTimer::singleShot(0, this, &OpenconnectAuthWidget::formGroupChanged);
                     }
                 }
             }
             if (sopt == AUTHGROUP_OPT(form)) {
-                connect(cmb, SIGNAL(currentIndexChanged(int)), this, SLOT(formGroupChanged()));
+                connect(cmb, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &OpenconnectAuthWidget::formGroupChanged);
             }
             widget = qobject_cast<QWidget*>(cmb);
         }
@@ -477,8 +484,9 @@ void OpenconnectAuthWidget::processAuthForm(struct oc_auth_form *form)
     }
     d->ui.loginBoxLayout->addLayout(layout);
     d->ui.loginBoxLayout->addWidget(togglePasswordMode);
-    if (passwordnumber == 0)
+    if (passwordnumber == 0) {
         togglePasswordMode->setVisible(false);
+    }
     QDialogButtonBox *box = new QDialogButtonBox(this);
     QPushButton *btn = box->addButton(QDialogButtonBox::Ok);
     btn->setText(i18n("Login"));
@@ -486,7 +494,7 @@ void OpenconnectAuthWidget::processAuthForm(struct oc_auth_form *form)
     d->ui.loginBoxLayout->addWidget(box);
     box->setProperty("openconnect_form", (quintptr)form);
 
-    connect(box, SIGNAL(accepted()), this, SLOT(formLoginClicked()));
+    connect(box, &QDialogButtonBox::accepted, this, &OpenconnectAuthWidget::formLoginClicked);
 }
 
 void OpenconnectAuthWidget::validatePeerCert(const QString &fingerprint,
@@ -547,8 +555,8 @@ void OpenconnectAuthWidget::validatePeerCert(const QString &fingerprint,
         dialog.data()->setWindowModality(Qt::WindowModal);
         dialog->setLayout(new QVBoxLayout);
         QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel, dialog);
-        connect(buttons, SIGNAL(accepted()), dialog, SLOT(accept()));
-        connect(buttons, SIGNAL(rejected()), dialog, SLOT(reject()));
+        connect(buttons, &QDialogButtonBox::accepted, dialog.data(), &QDialog::accept);
+        connect(buttons, &QDialogButtonBox::rejected, dialog.data(), &QDialog::reject);
         dialog->layout()->addWidget(widget);
         dialog->layout()->addWidget(buttons);
         connect(dialog.data(), &QDialog::finished,
@@ -569,8 +577,9 @@ void OpenconnectAuthWidget::validatePeerCert(const QString &fingerprint,
     } else {
         *accepted = true;
     }
-    if (*accepted)
+    if (*accepted) {
         d->secrets.insert(key, QString(fingerprint));
+    }
     d->mutex.lock();
     d->workerWaiting.wakeAll();
     d->mutex.unlock();
@@ -636,8 +645,9 @@ void OpenconnectAuthWidget::workerFinished(const int &ret)
                 break;
             }
         }
-        if (message.isEmpty())
+        if (message.isEmpty()) {
             message = i18n("Connection attempt was unsuccessful.");
+        }
         deleteAllFromLayout(d->ui.loginBoxLayout);
         addFormInfo(QLatin1String("dialog-error"), message);
     } else {
@@ -652,9 +662,9 @@ void OpenconnectAuthWidget::deleteAllFromLayout(QLayout *layout)
         if (QLayout *itemLayout = item->layout()) {
             deleteAllFromLayout(itemLayout);
             itemLayout->deleteLater();
-        }
-        else
+        } else {
             item->widget()->deleteLater();
+        }
         delete item;
     }
     layout->invalidate();
