@@ -52,7 +52,8 @@ public:
 
 
 OpenVpnSettingWidget::OpenVpnSettingWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget * parent)
-    : SettingWidget(setting, parent), d(new Private)
+    : SettingWidget(setting, parent)
+    , d(new Private)
 {
     qDBusRegisterMetaType<NMStringMap>();
 
@@ -65,22 +66,23 @@ OpenVpnSettingWidget::OpenVpnSettingWidget(const NetworkManager::VpnSetting::Ptr
     requesters << d->ui.x509CaFile << d->ui.x509Cert << d->ui.x509Key << d->ui.pskSharedKey << d->ui.passCaFile
                << d->ui.x509PassCaFile << d->ui.x509PassCert << d->ui.x509PassKey;
     Q_FOREACH (const KUrlRequester * requester, requesters) {
-        connect(requester, SIGNAL(urlSelected(QUrl)), this, SLOT(updateStartDir(QUrl)));
+        connect(requester, &KUrlRequester::urlSelected, this, &OpenVpnSettingWidget::updateStartDir);
     }
 
-    connect(d->ui.x509KeyPasswordStorage, SIGNAL(currentIndexChanged(int)), this, SLOT(x509KeyPasswordStorageChanged(int)));
-    connect(d->ui.passPasswordStorage, SIGNAL(currentIndexChanged(int)), this, SLOT(passPasswordStorageChanged(int)));
-    connect(d->ui.x509PassKeyPasswordStorage, SIGNAL(currentIndexChanged(int)), this, SLOT(x509PassKeyPasswordStorageChanged(int)));
-    connect(d->ui.x509PassPasswordStorage, SIGNAL(currentIndexChanged(int)), this, SLOT(x509PassPasswordStorageChanged(int)));
-    connect(d->ui.chkShowPasswords, SIGNAL(toggled(bool)), this, SLOT(showPasswordsToggled(bool)));
-    connect(d->ui.btnAdvanced, SIGNAL(clicked()), SLOT(showAdvanced()));
+    connect(d->ui.x509KeyPasswordStorage, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &OpenVpnSettingWidget::x509KeyPasswordStorageChanged);
+    connect(d->ui.passPasswordStorage, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &OpenVpnSettingWidget::passPasswordStorageChanged);
+    connect(d->ui.x509PassKeyPasswordStorage, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &OpenVpnSettingWidget::x509PassKeyPasswordStorageChanged);
+    connect(d->ui.x509PassPasswordStorage, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &OpenVpnSettingWidget::x509PassPasswordStorageChanged);
+    connect(d->ui.chkShowPasswords, &QCheckBox::toggled, this, &OpenVpnSettingWidget::showPasswordsToggled);
+    connect(d->ui.btnAdvanced, &QPushButton::clicked, this, &OpenVpnSettingWidget::showAdvanced);
 
-    connect(d->ui.gateway, SIGNAL(textChanged(QString)), SLOT(slotWidgetChanged()));
+    connect(d->ui.gateway, &QLineEdit::textChanged, this, &OpenVpnSettingWidget::slotWidgetChanged);
 
     KAcceleratorManager::manage(this);
 
-    if (d->setting)
+    if (d->setting) {
         loadConfig(d->setting);
+    }
 }
 
 OpenVpnSettingWidget::~OpenVpnSettingWidget()
@@ -95,7 +97,6 @@ void OpenVpnSettingWidget::loadConfig(const NetworkManager::Setting::Ptr &settin
     // General settings
     const NMStringMap dataMap = d->setting->data();
     const QString cType = dataMap.value(NM_OPENVPN_KEY_CONNECTION_TYPE);
-    const NMStringMap secrets = d->setting->secrets();
 
     if ( cType == QLatin1String( NM_OPENVPN_CONTYPE_PASSWORD_TLS ) ) {
         d->ui.cmbConnectionType->setCurrentIndex( Private::EnumConnectionType::CertsPassword);
@@ -107,8 +108,7 @@ void OpenVpnSettingWidget::loadConfig(const NetworkManager::Setting::Ptr &settin
         d->ui.cmbConnectionType->setCurrentIndex( Private::EnumConnectionType::Psk );
         d->ui.pskSharedKey->setText( dataMap[NM_OPENVPN_KEY_STATIC_KEY]);
         if (dataMap.contains(NM_OPENVPN_KEY_STATIC_KEY_DIRECTION)) {
-            switch (dataMap[NM_OPENVPN_KEY_STATIC_KEY_DIRECTION].toUInt())
-            {
+            switch (dataMap[NM_OPENVPN_KEY_STATIC_KEY_DIRECTION].toUInt()) {
             case 0:
                 d->ui.cmbKeyDirection->setCurrentIndex(Private::EnumKeyDirection::D0);
                 break;
@@ -138,28 +138,36 @@ void OpenVpnSettingWidget::loadConfig(const NetworkManager::Setting::Ptr &settin
 
     if (cType == QLatin1String(NM_OPENVPN_CONTYPE_TLS)) {
         type = (NetworkManager::Setting::SecretFlags)dataMap[NM_OPENVPN_KEY_CERTPASS"-flags"].toInt();
-        if (!(type & NetworkManager::Setting::NotSaved || type & NetworkManager::Setting::NotRequired)) {
-            d->ui.x509KeyPassword->setText(secrets.value(NM_OPENVPN_KEY_CERTPASS));
-        }
         fillOnePasswordCombo(d->ui.x509KeyPasswordStorage, type);
     } else if (cType == QLatin1String(NM_OPENVPN_CONTYPE_PASSWORD)) {
         type = (NetworkManager::Setting::SecretFlags)dataMap[NM_OPENVPN_KEY_PASSWORD"-flags"].toInt();
-        if (!(type & NetworkManager::Setting::NotSaved || type & NetworkManager::Setting::NotRequired)) {
-            d->ui.passPassword->setText(secrets.value(NM_OPENVPN_KEY_PASSWORD));
-        }
         fillOnePasswordCombo(d->ui.passPasswordStorage, type);
     } else if (cType == QLatin1String(NM_OPENVPN_CONTYPE_PASSWORD_TLS)) {
         type = (NetworkManager::Setting::SecretFlags)dataMap[NM_OPENVPN_KEY_PASSWORD"-flags"].toInt();
-        if (!(type & NetworkManager::Setting::NotSaved || type & NetworkManager::Setting::NotRequired)) {
-            d->ui.x509PassPassword->setText(secrets.value(NM_OPENVPN_KEY_PASSWORD));
-        }
         fillOnePasswordCombo(d->ui.x509PassPasswordStorage, type);
-
         type = (NetworkManager::Setting::SecretFlags)dataMap[NM_OPENVPN_KEY_CERTPASS"-flags"].toInt();
-        if (!(type & NetworkManager::Setting::NotSaved || type & NetworkManager::Setting::NotRequired)) {
+        fillOnePasswordCombo(d->ui.x509PassKeyPasswordStorage, type);
+    }
+
+    loadSecrets(setting);
+}
+
+void OpenVpnSettingWidget::loadSecrets(const NetworkManager::Setting::Ptr &setting)
+{
+    NetworkManager::VpnSetting::Ptr vpnSetting = setting.staticCast<NetworkManager::VpnSetting>();
+
+    if (vpnSetting) {
+        const QString cType = d->setting->data().value(NM_OPENVPN_KEY_CONNECTION_TYPE);
+        const NMStringMap secrets = vpnSetting->secrets();
+
+        if (cType == QLatin1String(NM_OPENVPN_CONTYPE_TLS)) {
+            d->ui.x509KeyPassword->setText(secrets.value(NM_OPENVPN_KEY_CERTPASS));
+        } else if (cType == QLatin1String(NM_OPENVPN_CONTYPE_PASSWORD)) {
+            d->ui.passPassword->setText(secrets.value(NM_OPENVPN_KEY_PASSWORD));
+        } else if (cType == QLatin1String(NM_OPENVPN_CONTYPE_PASSWORD_TLS)) {
+            d->ui.x509PassPassword->setText(secrets.value(NM_OPENVPN_KEY_PASSWORD));
             d->ui.x509PassKeyPassword->setText(secrets.value(NM_OPENVPN_KEY_CERTPASS));
         }
-        fillOnePasswordCombo(d->ui.x509PassKeyPasswordStorage, type);
     }
 }
 
@@ -174,8 +182,7 @@ QVariantMap OpenVpnSettingWidget::setting(bool agentOwned) const
 
     QString contype;
 
-    switch ( d->ui.cmbConnectionType->currentIndex())
-    {
+    switch ( d->ui.cmbConnectionType->currentIndex()) {
     case Private::EnumConnectionType::Certificates:
         contype = QLatin1String(NM_OPENVPN_CONTYPE_TLS);
         // qCDebug(PLASMA_NM) << "saving VPN TLS settings as urls:" << d->ui.x509CaFile->url() << d->ui.x509Cert->url() << d->ui.x509Key->url();
@@ -305,10 +312,11 @@ uint OpenVpnSettingWidget::handleOnePasswordType(const QComboBox * combo, const
         data.insert(key, QString::number(NetworkManager::Setting::NotSaved));
         break;
     case SettingWidget::EnumPasswordStorageType::Store:
-        if (agentOwned)
+        if (agentOwned) {
             data.insert(key, QString::number(NetworkManager::Setting::AgentOwned));
-        else
+        } else {
             data.insert(key, QString::number(NetworkManager::Setting::None));
+        }
         break;
     case SettingWidget::EnumPasswordStorageType::NotRequired:
         data.insert(key, QString::number(NetworkManager::Setting::NotRequired));
