@@ -36,23 +36,25 @@ public:
 };
 
 StrongswanSettingWidget::StrongswanSettingWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget * parent)
-    : SettingWidget(setting, parent), d_ptr(new StrongswanSettingWidgetPrivate)
+    : SettingWidget(setting, parent)
+    , d_ptr(new StrongswanSettingWidgetPrivate)
 {
     Q_D(StrongswanSettingWidget);
     d->ui.setupUi(this);
     d->setting = setting;
-    connect(d->ui.cboUserPassOptions, SIGNAL(currentIndexChanged(int)), this, SLOT(userPasswordTypeChanged(int)));
-    connect(d->ui.cboPrivateKeyPassOptions, SIGNAL(currentIndexChanged(int)), this, SLOT(privateKeyPasswordTypeChanged(int)));
-    connect(d->ui.cboPinOptions, SIGNAL(currentIndexChanged(int)), this, SLOT(pinTypeChanged(int)));
-    connect(d->ui.cmbMethod, SIGNAL(currentIndexChanged(int)), this, SLOT(methodChanged(int)));
-    connect(d->ui.cbShowPasswords, SIGNAL(toggled(bool)), this, SLOT(showPasswordsChanged(bool)));
+    connect(d->ui.cboUserPassOptions, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &StrongswanSettingWidget::userPasswordTypeChanged);
+    connect(d->ui.cboPrivateKeyPassOptions, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &StrongswanSettingWidget::privateKeyPasswordTypeChanged);
+    connect(d->ui.cboPinOptions, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &StrongswanSettingWidget::pinTypeChanged);
+    connect(d->ui.cmbMethod, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &StrongswanSettingWidget::methodChanged);
+    connect(d->ui.cbShowPasswords, &QCheckBox::toggled, this, &StrongswanSettingWidget::showPasswordsChanged);
 
-    connect(d->ui.leGateway, SIGNAL(textChanged(QString)), SLOT(slotWidgetChanged()));
+    connect(d->ui.leGateway, &QLineEdit::textChanged, this, &StrongswanSettingWidget::slotWidgetChanged);
 
     KAcceleratorManager::manage(this);
 
-    if (d->setting)
+    if (d->setting) {
         loadConfig(d->setting);
+    }
 }
 
 StrongswanSettingWidget::~StrongswanSettingWidget()
@@ -121,26 +123,50 @@ void StrongswanSettingWidget::loadConfig(const NetworkManager::Setting::Ptr &set
     d->ui.ipComp->setChecked(dataMap[NM_STRONGSWAN_IPCOMP] == "yes");
 
     // secrets
-    const NMStringMap secrets = d->setting->secrets();
     if (d->setting->data().value(NM_STRONGSWAN_SECRET_TYPE) == QLatin1String(NM_STRONGSWAN_PW_TYPE_SAVE)) {
-        switch (d->ui.cmbMethod->currentIndex())
-        {
+        switch (d->ui.cmbMethod->currentIndex()) {
         case StrongswanSettingWidgetPrivate::PrivateKey:
-            d->ui.lePrivateKeyPassword->setText(secrets.value(QLatin1String(NM_STRONGSWAN_SECRET)));
             fillOnePasswordCombo(d->ui.cboPrivateKeyPassOptions, NM_STRONGSWAN_SECRET_TYPE, d->setting->data(), !d->ui.leAuthPrivatekeyKey->url().isEmpty());
             break;
         case StrongswanSettingWidgetPrivate::Smartcard:
-            d->ui.lePin->setText(secrets.value(QLatin1String(NM_STRONGSWAN_SECRET)));
             fillOnePasswordCombo(d->ui.cboPinOptions, NM_STRONGSWAN_SECRET_TYPE, d->setting->data(), true);
             break;
         case StrongswanSettingWidgetPrivate::Eap:
-            d->ui.leUserPassword->setText(secrets.value(QLatin1String(NM_STRONGSWAN_SECRET)));
             fillOnePasswordCombo(d->ui.cboUserPassOptions, NM_STRONGSWAN_SECRET_TYPE, d->setting->data(), !d->ui.leUserName->text().isEmpty());
             break;
         default:
             break;
         }
     }
+
+    loadSecrets(setting);
+}
+
+void StrongswanSettingWidget::loadSecrets(const NetworkManager::Setting::Ptr &setting)
+{
+    Q_D(StrongswanSettingWidget);
+
+    NetworkManager::VpnSetting::Ptr vpnSetting = setting.staticCast<NetworkManager::VpnSetting>();
+
+    if (vpnSetting) {
+        const NMStringMap secrets = vpnSetting->secrets();
+
+        if (d->setting->data().value(NM_STRONGSWAN_SECRET_TYPE) == QLatin1String(NM_STRONGSWAN_PW_TYPE_SAVE)) {
+            switch (d->ui.cmbMethod->currentIndex()) {
+            case StrongswanSettingWidgetPrivate::PrivateKey:
+                d->ui.lePrivateKeyPassword->setText(secrets.value(QLatin1String(NM_STRONGSWAN_SECRET)));
+                break;
+            case StrongswanSettingWidgetPrivate::Smartcard:
+                d->ui.lePin->setText(secrets.value(QLatin1String(NM_STRONGSWAN_SECRET)));
+                break;
+            case StrongswanSettingWidgetPrivate::Eap:
+                d->ui.leUserPassword->setText(secrets.value(QLatin1String(NM_STRONGSWAN_SECRET)));
+                break;
+            default:
+                break;
+            }
+        }
+    }
 }
 
 QVariantMap StrongswanSettingWidget::setting(bool agentOwned) const
@@ -161,8 +187,7 @@ QVariantMap StrongswanSettingWidget::setting(bool agentOwned) const
     data.insert( NM_STRONGSWAN_CERTIFICATE, d->ui.leGatewayCertificate->url().toLocalFile());
 
     // Authentication
-    switch (d->ui.cmbMethod->currentIndex())
-    {
+    switch (d->ui.cmbMethod->currentIndex()) {
     case StrongswanSettingWidgetPrivate::PrivateKey:
         data.insert(NM_STRONGSWAN_METHOD, NM_STRONGSWAN_AUTH_KEY);
         data.insert(NM_STRONGSWAN_USERCERT, d->ui.leAuthPrivatekeyCertificate->url().toLocalFile());
@@ -215,18 +240,18 @@ uint StrongswanSettingWidget::handleOnePasswordType(const QComboBox * combo, con
 {
     const uint type = combo->currentIndex();
     switch (type) {
-        case 1:
-            data.insert(key, QString::number(NetworkManager::Setting::NotSaved));
-            break;
-        case 0:
-            if (agentOwned)
-                data.insert(key, QString::number(NetworkManager::Setting::AgentOwned));
-            else
-                data.insert(key, QString::number(NetworkManager::Setting::None));
-            break;
-        case 2:
-            data.insert(key, QString::number(NetworkManager::Setting::NotRequired));
-            break;
+    case 1:
+        data.insert(key, QString::number(NetworkManager::Setting::NotSaved));
+        break;
+    case 0:
+        if (agentOwned)
+            data.insert(key, QString::number(NetworkManager::Setting::AgentOwned));
+        else
+            data.insert(key, QString::number(NetworkManager::Setting::None));
+        break;
+    case 2:
+        data.insert(key, QString::number(NetworkManager::Setting::NotRequired));
+        break;
     }
     return type;
 }
